from django.http import HttpResponse
from django.shortcuts import render_to_response
import datetime
from django.contrib import auth
from django.http import HttpResponseRedirect
from django.contrib.sessions.models import Session
from django.core.exceptions import ObjectDoesNotExist
# vands_db
from vands.vands_app.models import Appearance, UserInstrument, InstrumentModel, UserBand, Band, User, BandRequest, PracticeLocal, BandTimetable

def login_form(request):
	return render_to_response('login_form.html')
	
def login(request):
	username = request.POST['username']
	password = request.POST['password']
	user = auth.authenticate(username=username, password=password)
	if user is not None and user.is_active:
        # Clave correcta, y el usuario esta marcado "activo"
		auth.login(request, user)
		request.session['user'] = user
        # Redirigir a una pagina de exito.
		return HttpResponseRedirect('/room')
	else:
        # Mostrar una pagina de error
		errors=[];
		errors.append('Error en login: Nombre de usuario o Password incorrecto');
		return render_to_response('login_form.html',{'errors':errors})
		
def logout(request):
	if 'user' in request.session:
		del request.session['user']
	return HttpResponseRedirect('/login-form')

def room(request):
	if 'user' in request.session and request.session['user'].is_authenticated():
		return render_to_response('room.html')
	else:
		return HttpResponseRedirect('/login-form')
	
def room_clases_render(request):	
	appearance = Appearance.objects.get(user=request.session['user'])
	instruments = UserInstrument.objects.get(user=request.session['user'])
	models = instruments.instrument.order_by('type')
	try:
		band_requests = []
		requests = BandRequest.objects.filter(user=request.session['user'])
		for request in requests:	
			band_name = request.band.name;
			band_requests.append({
				'request_username': request.request_username,
				'band_name': band_name,
			})		
	except ObjectDoesNotExist,e:
		band_requests = []
	return render_to_response('src/room/clases.js', {'appearance':appearance, 'models':models, 'band_requests':band_requests})

def bands(request):
	if 'user' in request.session and request.session['user'].is_authenticated():
		return render_to_response('bands.html')
	else:
		return HttpResponseRedirect('/login-form')
	
def bands_clases_render(request):	
	appearance = Appearance.objects.get(user=request.session['user'])
	userbands = UserBand.objects.get(user=request.session['user'])
	bandas = userbands.bands.order_by('id')
	datos_bandas=[]
	for banda in bandas:
		datos_banda=[]
		datos_banda.append(banda.name)
		miembros=banda.members.order_by('id');
		for miembro in miembros:
			datos_banda.append(miembro.username)
		datos_bandas.append(datos_banda);
	return render_to_response('src/bands/clases.js', {'appearance':appearance, 'datos_bandas':datos_bandas})

def nueva_banda(request,name):
	b=Band.objects.create(name=name)
	b.members.add(request.session['user'])
	b.save()
	ub=UserBand.objects.get(user=request.session['user'])
	ub.bands.add(Band.objects.get(name=name))
	ub.save()
	return HttpResponseRedirect('/bands')
	
def borrar_banda(request,name):
	b=Band.objects.get(name=name)
	b.delete()
	return HttpResponseRedirect('/bands')

def nuevo_miembro(request,name):
	b=Band.objects.get(name=name)
	b.members.add(request.session['user'])
	b.save()
	ub=UserBand.objects.get(user=request.session['user'])
	ub.bands.add(Band.objects.get(name=name))
	ub.save()
	return HttpResponseRedirect('borrar_peticion_'+name+'_1')

def borrar_miembro(request,username,bandname):
	u=User.objects.get(username=username)
	b=Band.objects.get(name=bandname)
	b.members.remove(u)
	b.save()
	ub=UserBand.objects.get(user=u)
	ub.bands.remove(b)
	ub.save()
	return HttpResponseRedirect('/bands/')

def nueva_peticion(request,username,bandname):
	u = User.objects.get(username=username)
	b = Band.objects.get(name=bandname)
	ru = request.session['user'].username	
	br=BandRequest.objects.create(user=u,band=b,request_username=ru)
	br.save()	
	return HttpResponseRedirect('/bands/')
	
def borrar_peticion(request,bandname,aceptar):
	b=Band.objects.get(name=bandname)
	br=BandRequest.objects.filter(user=request.session['user'],band=b)
	br.delete()
	if aceptar == 1:
		return HttpResponseRedirect('/bands')
	else:
		return HttpResponseRedirect('/room')

def confirmarmiembro(request):	
	return render_to_response('confirmarmiembro.html')
	
def confirmarmiembro_clases_render(request,username,bandname):
	try:
		user = User.objects.get(username=username)
		appearance = Appearance.objects.get(user=user)
		error = 0
	except ObjectDoesNotExist,e:
		appearance = username
		error = 1
	return render_to_response('src/confirmarmiembro/clases.js', {'appearance':appearance, 'bandname':bandname, 'error':error})

def confirmarmiembro_javascript_file(request,name):
	path = 'src/confirmarmiembro/'+name+'.js'
	return render_to_response(path)	
	
def horario(request):	
	return render_to_response('horario.html')
	
def horario_clases_render(request):
	userbands = UserBand.objects.get(user=request.session['user'])
	bandas = userbands.bands.order_by('id')
	bands_timetable=[]
	for banda in bandas:
		band_timetables=BandTimetable.objects.filter(band__exact=banda)
		for bt in band_timetables:
			bands_timetable.append(bt)
	return render_to_response('src/horario/clases.js', {'bands_timetable':bands_timetable,'bandas':bandas})
	
def nuevo_horario(request,bandname,dia,hora_inicio,hora_fin):
	b = Band.objects.get(name=bandname)
	l = PracticeLocal.objects.get(name="Garage")
	bt = BandTimetable.objects.create(band=b,local=l,dia=dia,hora_inicio=hora_inicio,hora_fin=hora_fin)
	bt.save()
	return HttpResponseRedirect('/horario')
	
def borrar_horario(request,bandname,dia,hora_inicio):
	b = Band.objects.get(name=bandname)
	l = PracticeLocal.objects.get(name="Garage")
	bt = BandTimetable.objects.get(band=b,local=l,dia=dia,hora_inicio=hora_inicio)
	bt.delete()
	return HttpResponseRedirect('/horario')
	
def javascript_file(request,scenario,name):
	path='src/'+scenario+'/'+name+'.js';
	return render_to_response(path)
